sched: Kill old ->post_select variant.
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index d5834b4c436eafae77cb7a086c045c4bf6f0a81b..896f974c7c1aa2dcc871acd13c89b098274793a9 100644 (file)
--- a/write.h
+++ b/write.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2010 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2013 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -19,8 +19,11 @@ struct writer_node {
        void *private_data;
        /** The writer-specific configuration of this node. */
        void *conf;
+       /** The buffer tree node associated with this writer node. */
        struct btr_node *btrn;
+       /** The task of this writer node. */
        struct task task;
+       /** The minimal input queue size (size of one audio sample). */
        size_t min_iqs;
 };
 
@@ -36,14 +39,14 @@ struct writer {
        /**
         * The command line parser of the writer.
         *
* It should check whether the command line options given by \a options
* are valid and return a pointer to the writer-specific configuration
* data determined by \a options. This function must either succeed or
* call exit(). Note that parse_config_or_die() might be called more
* than once with different values of \a options. \sa \ref
* free_config().
         */
-       void *(*parse_config_or_die)(const char *options);
+       void *(*parse_config_or_die)(int argc, char **argv);
        /**
         * Dellocate all configuration resources.
         *
@@ -62,20 +65,21 @@ struct writer {
         *
         * Called from the post_select function of the writer node's task.
         */
-       void (*post_select)(struct sched *s, struct task *t);
+       int (*new_post_select)(struct sched *s, struct task *t);
        /**
         * Close one instance of the writer.
         *
         * This function is assumed to succeed.
         */
        void (*close)(struct writer_node *);
+       /** The short and the log help text of this writer. */
+       struct ggo_help help;
        /**
-        * Shutdown the writer
+        * The callback handler.
         *
-        * This is a optional function pointer used for cleaning up.
+        * Each writer may provide an ->execute callback which can be used for
+        * inter-node communication.
         */
-       void (*shutdown)(struct writer_node *);
-       struct ggo_help help;
        btr_command_handler execute;
 };
@@ -36,14 +39,14 @@ struct writer {
         * The command line parser of the writer.
         *
-        * It should check whether the command line options given by \a options
-        * are valid and return a pointer to the writer-specific configuration
-        * data determined by \a options. This function must either succeed or
-        * call exit(). Note that parse_config_or_die() might be called more
-        * than once with different values of \a options. \sa \ref
-        * free_config().
+        * It should check whether the command line options given by \a argv
+        * and \a argc are valid and return a pointer to the writer-specific
+        * configuration data determined by these options. This function must
+        * either succeed or call exit(). Note that parse_config_or_die() might
+        * be called more than once with different values of \a options. \sa
+        * \ref free_config().
         */